@@ -399,6 +399,26 @@
         <source>NaturalLog Reconciliation</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>LiveAssist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previous</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Classical Music Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>reserved</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -511,7 +531,7 @@
     </message>
     <message>
         <source>The name is invalid!</source>
-        <translation>Název je neplatný!</translation>
+        <translation type="obsolete">Název je neplatný!</translation>
     </message>
     <message>
         <source>The service is invalid!</source>
@@ -819,6 +839,10 @@ ze &amp;souboru</translation>
         <source>End</source>
         <translation type="unfinished">Konec</translation>
     </message>
+    <message>
+        <source>&amp;Recue</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDCueEditDialog</name>
