@@ -395,6 +395,26 @@
         <source>NaturalLog Reconciliation</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>LiveAssist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previous</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Classical Music Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>reserved</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -503,7 +523,7 @@
     </message>
     <message>
         <source>The name is invalid!</source>
-        <translation>¡El nombre es inválido!</translation>
+        <translation type="obsolete">¡El nombre es inválido!</translation>
     </message>
     <message>
         <source>&amp;Service:</source>
@@ -814,6 +834,10 @@ Color</translation>
         <source>End</source>
         <translation type="unfinished">Final</translation>
     </message>
+    <message>
+        <source>&amp;Recue</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDCueEditDialog</name>
