@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart_search_text.h,v 1.6 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdcart_search_text.h,v 1.10.4.1 2012/10/09 00:12:29 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,8 +28,10 @@
 #include <rdstation.h>
 
 
-QString RDCartSearchText(QString filter,QString group);
-QString RDAllCartSearchText(QString filter,QString user);
+QString RDCartSearchText(QString filter,const QString &group,
+			 const QString &schedcode,bool incl_cuts);
+QString RDAllCartSearchText(const QString &filter,const QString &schedcode,
+			    const QString &user,bool incl_cuts);
 
 
 #endif 
