@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlivewire.cpp,v 1.7.8.1 2013/01/30 21:06:04 cvs Exp $
+//      $Id: rdlivewire.cpp,v 1.7.8.2 2013/11/17 02:03:19 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,7 +22,9 @@
 
 #include <stdlib.h>
 #include <syslog.h>
+#include <unistd.h>
 
+#include <qapplication.h>
 #include <qsignalmapper.h>
 
 #include <rd.h>
@@ -42,6 +44,7 @@ RDLiveWire::RDLiveWire(unsigned id,QObject *parent,const char *name)
   live_base_output=0;
   live_ptr=0;
   live_connected=false;
+  live_load_ver_count=0;
 
   //
   // Connection Socket
@@ -103,6 +106,24 @@ void RDLiveWire::connectToHost(const QString &hostname,Q_UINT16 port,
 }
 
 
+bool RDLiveWire::loadSettings(const QString &hostname,Q_UINT16 port,
+			      const QString &passwd,unsigned base_output)
+{
+  int passes=50;
+
+  live_load_ver_count=1;
+  connectToHost(hostname,port,passwd,base_output);
+  while(--passes>0) {
+    usleep(100000);
+    qApp->processEvents();
+    if(live_load_ver_count==0) {
+      return true;
+    }
+  }
+  return false;
+}
+
+
 QString RDLiveWire::deviceName() const
 {
   return live_device_name;
@@ -198,6 +219,7 @@ void RDLiveWire::gpiSet(int slot,int line,unsigned interval)
     live_gpi_timers[slot*RD_LIVEWIRE_GPIO_BUNDLE_SIZE+line]->
       start(interval,true);
   }
+  emit gpiChanged(live_id,slot,line,true);
 }
 
 
@@ -224,6 +246,7 @@ void RDLiveWire::gpiReset(int slot,int line,unsigned interval)
     live_gpi_timers[slot*RD_LIVEWIRE_GPIO_BUNDLE_SIZE+line]->
       start(interval,true);
   }
+  emit gpiChanged(live_id,slot,line,false);
 }
 
 
@@ -250,6 +273,7 @@ void RDLiveWire::gpoSet(int slot,int line,unsigned interval)
     live_gpo_timers[slot*RD_LIVEWIRE_GPIO_BUNDLE_SIZE+line]->
       start(interval,true);
   }
+  emit gpoChanged(live_id,slot,line,true);
 }
 
 
@@ -276,6 +300,7 @@ void RDLiveWire::gpoReset(int slot,int line,unsigned interval)
     live_gpo_timers[slot*RD_LIVEWIRE_GPIO_BUNDLE_SIZE+line]->
       start(interval,true);
   }
+  emit gpoChanged(live_id,slot,line,false);
 }
 
 
@@ -375,7 +400,7 @@ void RDLiveWire::gpiTimeoutData(int id)
   int chan=id/RD_LIVEWIRE_GPIO_BUNDLE_SIZE;
   int line=id%RD_LIVEWIRE_GPIO_BUNDLE_SIZE;
 
-  QString cmd=QString().sprintf("GPI %d CMD:\"GPI %d ",chan+1,chan+1);
+  QString cmd=QString().sprintf("GPI %d ",chan+1);
   for(int i=0;i<RD_LIVEWIRE_GPIO_BUNDLE_SIZE;i++) {
     if(i==line) {
       if(live_gpi_states[chan][i]) {
@@ -394,9 +419,10 @@ void RDLiveWire::gpiTimeoutData(int id)
       }
     }
   }
-  cmd+="\"\n";
+  cmd+="\"\r\n";
   live_socket->writeBlock(cmd,cmd.length());
   live_gpi_states[chan][line]=!live_gpi_states[chan][line];
+  emit gpiChanged(live_id,chan,line,live_gpi_states[chan][line]);
 }
 
 
@@ -427,6 +453,7 @@ void RDLiveWire::gpoTimeoutData(int id)
   cmd+="\r\n";
   live_socket->writeBlock(cmd,cmd.length());
   live_gpo_states[chan][line]=!live_gpo_states[chan][line];
+  emit gpoChanged(live_id,chan,line,live_gpo_states[chan][line]);
 }
 
 
@@ -524,7 +551,7 @@ void RDLiveWire::ReadVersion(const QString &cmd)
 	  live_channels=value.right(value.length()-delimiter-1).toInt();
 	}
 	if(live_sources>0) {
-	  live_socket->writeBlock("SRC\n",4);
+	  live_socket->writeBlock("SRC\r\n",5);
 	}
       }
       if(tag=="NDST") {
@@ -537,7 +564,7 @@ void RDLiveWire::ReadVersion(const QString &cmd)
 	  live_channels=value.right(value.length()-delimiter-1).toInt();
 	}
 	if(live_destinations>0) {
-	  live_socket->writeBlock("DST\n",4);
+	  live_socket->writeBlock("DST\r\n",5);
 	}
       }
       if(tag=="NGPI") {
@@ -558,7 +585,7 @@ void RDLiveWire::ReadVersion(const QString &cmd)
 	  }	
 	}
 	if(live_gpis>0) {
-	  live_socket->writeBlock("ADD GPI\n",8);
+	  live_socket->writeBlock("ADD GPI\r\n",9);
 	}
       }
       if(tag=="NGPO") {
@@ -579,14 +606,17 @@ void RDLiveWire::ReadVersion(const QString &cmd)
 	  }
 	}
 	if(live_gpos>0) {
-	  live_socket->writeBlock("CFG GPO\n",8);
-	  live_socket->writeBlock("ADD GPO\n",8);
+	  live_socket->writeBlock("CFG GPO\r\n",9);
+	  live_socket->writeBlock("ADD GPO\r\n",9);
 	}
       }
     }
     live_connected=true;
     emit connected(live_id);
   }
+  if(live_load_ver_count>0) {
+    live_load_ver_count--;
+  }
   if(live_watchdog_state) {
     live_watchdog_state=false;
     emit watchdogStateChanged(live_id,QString().sprintf(
