@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_line.h,v 1.85.8.4 2013/03/09 00:21:11 cvs Exp $
+//      $Id: rdlog_line.h,v 1.85.8.10.2.1 2014/05/20 01:45:16 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -144,14 +144,22 @@ class RDLogLine
   void setIsci(const QString &string);
   QString label() const;
   void setLabel(const QString &label);
+  QString conductor() const;
+  void setConductor(const QString &cond);
+  QString songId() const;
+  void setSongId(const QString &id);
   QString client() const;
   void setClient(const QString &client);
   QString agency() const;
   void setAgency(const QString &agency);
   QString outcue() const;
   void setOutcue(const QString &outcue);
+  QString description() const;
+  void setDescription(const QString &desc);
   QString userDefined() const;
   void setUserDefined(const QString &string);
+  QString cartNotes() const;
+  void setCartNotes(const QString &str);
   RDCart::UsageCode usageCode() const;
   void setUsageCode(RDCart::UsageCode code);
   unsigned forcedLength() const;
@@ -223,6 +231,10 @@ class RDLogLine
   void setPlayPositionChanged(bool state);
   bool nowNextEnabled() const;
   void setNowNextEnabled(bool state);
+  bool useEventLength() const;
+  void setUseEventLength(bool state);
+  int eventLength() const;
+  void setEventLength(int msec);
   QString linkEventName() const;
   void setLinkEventName(const QString &name);
   QTime linkStartTime() const;
@@ -246,11 +258,15 @@ class RDLogLine
 		bool timescale,RDLogLine::TransType type=RDLogLine::NoTrans,
 		int len=-1);
   void refreshPointers();
+  QString xml(int line) const;
   static QString resolveWildcards(unsigned cartnum,const QString &pattern);
   static QString startSourceText(RDLogLine::StartSource src);
   static QString transText(RDLogLine::TransType trans);
   static QString typeText(RDLogLine::Type type);
+  static QString timeTypeText(RDLogLine::TimeType type);
   static QString sourceText(RDLogLine::Source src);
+  bool isHoldover() const;
+  void setHoldover(bool);
 
  private:
   int log_id;
@@ -292,10 +308,14 @@ class RDLogLine
   QString log_isci;
   QDate log_year;
   QString log_label;
+  QString log_conductor;
+  QString log_song_id;
   QString log_client;
   QString log_agency;
   QString log_outcue;
+  QString log_description;
   QString log_user_defined;
+  QString log_cart_notes;
   RDCart::UsageCode log_usage_code;
   unsigned log_forced_length;
   unsigned log_cut_quantity;
@@ -341,6 +361,8 @@ class RDLogLine
   bool log_asyncronous;
   QString log_cut_name;
   bool log_has_custom_transition;
+  bool log_use_event_length;
+  int log_event_length;
   QString log_link_event_name;
   QTime log_link_start_time;
   int log_link_length;
@@ -348,6 +370,7 @@ class RDLogLine
   int log_link_end_slop;
   int log_link_id;
   bool log_link_embedded;
+  bool is_holdover;
 };
 
 
