@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpanel_button.h,v 1.14 2007-07-15 20:51:31 stgabriel Exp $
+//      $Id: rdpanel_button.h,v 1.18.6.5 2014/02/06 20:43:47 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,6 +33,7 @@
 #include <rdairplay_conf.h>
 #include <rdplay_deck.h>
 #include <rdlog_line.h>
+#include <rdcartdrag.h>
 
 #define RDPANEL_BUTTON_MARGIN 5
 
@@ -40,7 +41,8 @@ class RDPanelButton : public QPushButton
 {
  Q_OBJECT
  public:
-  RDPanelButton(RDStation *station,bool flash,QWidget *parent=0,const char *name=0);
+  RDPanelButton(int row,int col,RDStation *station,bool flash,QWidget *parent=0,
+		const char *name=0);
   void clear();
   QString text() const;
   void setText(const QString &text);
@@ -75,7 +77,12 @@ class RDPanelButton : public QPushButton
   void setPauseWhenFinished(bool pause_when_finished);
   int duckVolume() const;
   void setDuckVolume(int lvel);
-  void WriteKeycap(int secs=-1);
+  void setAllowDrags(bool state);
+  void resetCounter();
+
+ signals:
+  void cartDropped(int row,int col,unsigned cartnum,const QColor &color,
+		   const QString &title);
 
  public slots:
   void tickClock();
@@ -85,10 +92,17 @@ class RDPanelButton : public QPushButton
   void keyPressEvent(QKeyEvent *e);
   void keyReleaseEvent(QKeyEvent *e);
 
+ protected:
+  void mousePressEvent(QMouseEvent *e);
+  void mouseMoveEvent(QMouseEvent *e);
+  void mouseReleaseEvent(QMouseEvent *e);
+  void dragEnterEvent(QDragEnterEvent *e);
+  void dropEvent(QDropEvent *e);
+
  private:
+  void WriteKeycap(int secs);
   QString WrapText(QString text,int *lines);
   QString GetNextLine(QString *str,const QFontMetrics &m,int len);
-  QPalette button_default_palette;
   QColor button_default_color;
   QWidget *button_parent;
   QString button_text;
@@ -109,9 +123,14 @@ class RDPanelButton : public QPushButton
   int button_output;
   bool button_flash;
   bool button_flashing;
+  bool button_flash_state;
   bool button_state;
   bool button_pause_when_finished;
   int button_duck_volume;
   RDLogLine::StartSource button_start_source;
+  int button_row;
+  int button_col;
+  int button_move_count;
+  bool button_allow_drags;
 };
 #endif
