@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: loglinebox.cpp,v 1.89 2011/05/20 20:46:44 cvs Exp $
+//      $Id: loglinebox.cpp,v 1.89.6.8 2014/02/06 20:43:50 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,6 +24,8 @@
 
 #include <rdconf.h>
 #include <rdplay_deck.h>
+#include <rdairplay_conf.h>
+#include <rdnownext.h>
 
 #include <loglinebox.h>
 #include <colors.h>
@@ -39,15 +41,26 @@
 #include "../icons/music.xpm"
 
 
-LogLineBox::LogLineBox(QWidget *parent,const char *name)
+LogLineBox::LogLineBox(RDAirPlayConf *conf,QWidget *parent,const char *name)
   : QWidget(parent,name)
 {
+  line_status=RDLogLine::Scheduled;
   line_type=RDLogLine::UnknownType;
   line_mode=LogLineBox::Full;
   line_time_mode=RDAirPlayConf::TwentyFourHour;
   line_logline=NULL;
   log_id=-1;
   log_line=-1;
+  line_move_count=-1;
+  line_allow_drags=false;
+
+  //
+  // Templates
+  //
+  line_title_template=conf->titleTemplate();
+  line_artist_template=conf->artistTemplate();
+  line_outcue_template=conf->outcueTemplate();
+  line_description_template=conf->descriptionTemplate();
 
   //
   // Create Font
@@ -121,7 +134,7 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Count Up
   //
-  line_up_label=new QLabel(this,"line_up_label");
+  line_up_label=new QLabel(this);
   line_up_label->setGeometry(5,65,65,16);
   line_up_label->setAlignment(AlignLeft|AlignVCenter);
   line_up_label->setFont(line_font);
@@ -130,7 +143,7 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Position Slider
   //
-  line_position_bar=new QProgressBar(this,"line_position_bar");
+  line_position_bar=new QProgressBar(this);
   line_position_bar->setGeometry(75,66,sizeHint().width()-150,13);
   line_position_bar->setPercentageVisible(false);
   line_position_bar->hide();
@@ -138,7 +151,7 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Count Down
   //
-  line_down_label=new QLabel(this,"line_down_label");
+  line_down_label=new QLabel(this);
   line_down_label->setGeometry(sizeHint().width()-72,65,65,16);
   line_down_label->setAlignment(AlignLeft|AlignVCenter);
   line_down_label->setFont(line_font);
@@ -147,7 +160,7 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Cut Description
   //
-  line_description_label=new QLabel(this,"line_description_label");
+  line_description_label=new QLabel(this);
   line_description_label->setGeometry((sizeHint().width()/2),48,(sizeHint().width()/2 -10),16);
   line_description_label->setFont(line_font);
   line_description_label->hide();
@@ -155,7 +168,7 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Outcue
   //
-  line_outcue_label=new QLabel(this,"line_outcue_label");
+  line_outcue_label=new QLabel(this);
   line_outcue_label->setGeometry(5,48, (sizeHint().width()/2 -10),16);
   line_outcue_label->setFont(outcue_font);
   line_outcue_label->hide();
@@ -163,21 +176,21 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Artist
   //
-  line_artist_label=new QLabel(this,"line_artist_label");
+  line_artist_label=new QLabel(this);
   line_artist_label->setGeometry(5,33,sizeHint().width()-10,16);
   line_artist_label->setFont(line_font);
 
   //
   // Title
   //
-  line_title_label=new QLabel(this,"line_title_label");
+  line_title_label=new QLabel(this);
   line_title_label->setGeometry(5,18,sizeHint().width()-10,18);
   line_title_label->setFont(line_bold_font);
 
   //
   // Marker Comment
   //
-  line_comment_label=new RDLabel(this,"line_comment_label");
+  line_comment_label=new RDLabel(this);
   line_comment_label->setGeometry(5,18,sizeHint().width()-10,62);
   line_comment_label->setFont(line_font);
   line_comment_label->setAlignment(AlignTop|AlignLeft);
@@ -187,35 +200,35 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Icon
   //
-  line_icon_label=new QLabel(this,"line_icon_label");
+  line_icon_label=new QLabel(this);
   line_icon_label->setGeometry(5,3,45,16);
 
   //
   // Cart
   //
-  line_cart_label=new QLabel(this,"line_cart_label");
+  line_cart_label=new QLabel(this);
   line_cart_label->setGeometry(25,3,53,16);
   line_cart_label->setFont(line_font);
 
   //
   // Cut
   //
-  line_cut_label=new QLabel(this,"line_cut_label");
+  line_cut_label=new QLabel(this);
   line_cut_label->setGeometry(80,3,24,16);
   line_cut_label->setFont(line_font);
 
   //
   // Group
   //
-  line_group_label=new QLabel(this,"line_group_label");
+  line_group_label=new QLabel(this);
   line_group_label->setGeometry(107,3,75,16);
   line_group_label->setFont(line_bold_font);
 
   //
   // Time
   //
-  line_time_label=new QLabel(this,"line_time_label");
-  line_time_label->setGeometry(185,3,85,16);
+  line_time_label=new QLabel(this);
+  line_time_label->setGeometry(185,3,70,16);
   line_time_label->setFont(line_font);
   line_time_label->setAlignment(AlignRight);
   line_time_label->setPalette(line_time_palette);
@@ -223,15 +236,15 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Talk Time
   //
-  line_talktime_label=new QLabel(this,"line_talktime_label");
-  line_talktime_label->setGeometry(273,3,21,16);
+  line_talktime_label=new QLabel(this);
+  line_talktime_label->setGeometry(257,3,36,16);
   line_talktime_label->setFont(talk_font);
   line_talktime_label->setAlignment(AlignRight);
 
   //
   // Length
   //
-  line_length_label=new QLabel(this,"line_length_label");
+  line_length_label=new QLabel(this);
   line_length_label->setGeometry(297,3,40,16);
   line_length_label->setFont(line_font);
   line_length_label->setAlignment(AlignRight);
@@ -239,7 +252,7 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Transition Type
   //
-  line_trans_label=new QLabel(this,"line_trans_label");
+  line_trans_label=new QLabel(this);
   line_trans_label->setGeometry(sizeHint().width()-53,3,48,16);
   line_trans_label->setAlignment(AlignRight);
   line_trans_label->setFont(line_bold_font);
@@ -249,8 +262,10 @@ LogLineBox::LogLineBox(QWidget *parent,const char *name)
   //
   // Countdown Timer
   //
-  line_countdown_timer=new QTimer(this,"line_countdown_timer");
+  line_countdown_timer=new QTimer(this);
   connect(line_countdown_timer,SIGNAL(timeout()),this,SLOT(countdownData()));
+
+  setAcceptDrops(true);
 }
 
 
@@ -293,6 +308,12 @@ void LogLineBox::setLine(int line)
 }
 
 
+void LogLineBox::setAllowDrags(bool state)
+{
+  line_allow_drags=state;
+}
+
+
 RDLogLine *LogLineBox::logLine()
 {
   return line_logline;
@@ -359,6 +380,7 @@ void LogLineBox::setStatus(RDLogLine::Status status)
 	line_outcue_label->show();
 	break;
   }
+  line_status=status;
 }
 
 
@@ -405,8 +427,7 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
   case RDLogLine::Cart:
     line_comment_label->hide();
     cart=new RDCart(logline->cartNumber());
-    cut=new RDCut(QString().sprintf("%06u_%03u",logline->cartNumber(),
-				    logline->cutNumber()));
+    cut=new RDCut(logline->cartNumber(),logline->cutNumber());
     if(!cart->exists()) {
       line_cart_label->
 	setText(QString().sprintf("%06u",logline->cartNumber()));
@@ -498,9 +519,11 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	else {
 	  line_length_label->setPalette(line_time_palette);
 	}
-	if(line_logline->originUser().isEmpty()||
+	if((line_logline->source()!=RDLogLine::Tracker)||
+	   line_logline->originUser().isEmpty()||
 	   (!line_logline->originDateTime().isValid())) {
-	  line_title_label->setText(line_logline->title());
+	  line_title_label->
+	    setText(RDResolveNowNext(line_title_template,line_logline));
 	}
 	else {
 	  line_title_label->setText(QString().
@@ -510,8 +533,10 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 					    (const char *)line_logline->originDateTime().
 					    toString("M/d hh:mm")));
 	}
-	line_description_label->setText(cut->description());
-	line_artist_label->setText(cart->artist());
+	line_description_label->
+	  setText(RDResolveNowNext(line_description_template,line_logline));
+	line_artist_label->
+	  setText(RDResolveNowNext(line_artist_template,line_logline));
 	line_up_label->
 	  setText(RDGetTimeLength(line_logline->playPosition(),true,true));
 	line_down_label->
@@ -522,7 +547,8 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
 	if(logline->cutNumber()>=0) {
 	  line_cut_label->
 	    setText(QString().sprintf("%03u",logline->cutNumber()));
-	  line_outcue_label->setText(logline->outcue());
+	  line_outcue_label->
+	    setText(RDResolveNowNext(line_outcue_template,line_logline));
 	}
 	else {
 	  SetColor(QColor(LOGLINEBOX_MISSING_COLOR));
@@ -635,10 +661,15 @@ void LogLineBox::setEvent(int line,RDLogLine::TransType next_type,
     line_length_label->
       setText(RDGetTimeLength(line_logline->effectiveLength(),
 			      false,false));
-    line_title_label->setText(cart->title());
-    line_description_label->setText("");
-    line_artist_label->setText(cart->artist());
-    line_outcue_label->setText("");
+
+    line_title_label->
+      setText(RDResolveNowNext(line_title_template,line_logline));
+    line_description_label->
+      setText(RDResolveNowNext(line_description_template,line_logline));
+    line_artist_label->
+      setText(RDResolveNowNext(line_artist_template,line_logline));
+    line_outcue_label->
+      setText(RDResolveNowNext(line_outcue_template,line_logline));
     delete cart;
     delete cut;
     setMode(line_mode);
@@ -747,6 +778,34 @@ void LogLineBox::countdownData()
 }
 
 
+void LogLineBox::mousePressEvent(QMouseEvent *e)
+{
+  QWidget::mousePressEvent(e);
+  line_move_count=3;
+}
+
+
+void LogLineBox::mouseMoveEvent(QMouseEvent *e)
+{
+  QWidget::mouseMoveEvent(e);
+  line_move_count--;
+  if(line_move_count==0) {
+    if(line_allow_drags&&(line_logline!=NULL)) {
+      RDCartDrag *d=
+	new RDCartDrag(line_logline->cartNumber(),line_icon_label->pixmap(),
+		       this);
+      d->dragCopy();
+    }
+  }
+}
+
+
+void LogLineBox::mouseReleaseEvent(QMouseEvent *e)
+{
+  line_move_count=-1;
+}
+
+
 void LogLineBox::mouseDoubleClickEvent(QMouseEvent *e)
 {
   if(line_logline==NULL) {
@@ -766,9 +825,26 @@ void LogLineBox::paintEvent(QPaintEvent *e)
 }
 
 
+void LogLineBox::dragEnterEvent(QDragEnterEvent *e)
+{
+  e->accept(RDCartDrag::canDecode(e)&&(line_status==RDLogLine::Scheduled));
+}
+
+
+void LogLineBox::dropEvent(QDropEvent *e)
+{
+  RDLogLine ll;
+
+  if(RDCartDrag::decode(e,&ll)) {
+    emit cartDropped(log_line,&ll);
+  }
+}
+
+
 void LogLineBox::SetColor(QColor color)
 {
   setBackgroundColor(color);
+  //  color=Qt::red;
   line_cart_label->setBackgroundColor(color);
   line_cut_label->setBackgroundColor(color);
   line_group_label->setBackgroundColor(color);
