@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.cpp,v 1.130.2.8.2.3 2010/05/19 16:43:53 cvs Exp $
+//      $Id: rdcatchd.cpp,v 1.142.4.2.2.1 2014/06/03 18:23:38 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,6 +33,8 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #include <errno.h>
+#include <sched.h>
+#include <sys/mman.h>
 
 #include <vector>
 
@@ -59,6 +61,7 @@
 #include <rdsettings.h>
 #include <rdlibrary_conf.h>
 #include <rdpaths.h>
+#include <dbversion.h>
 
 RDConfig *catch_config;
 
@@ -123,6 +126,8 @@ MainObject::MainObject(QObject *parent,const char *name)
 {
   QString sql;
   RDSqlQuery *q;
+  bool skip_db_check=false;
+  unsigned schema=0;
 
   //
   // Load the config
@@ -140,6 +145,9 @@ MainObject::MainObject(QObject *parent,const char *name)
       RunBatch(cmd);
       return;
     }
+    if(cmd->key(i)=="--skip-db-check") {
+      skip_db_check=true;
+    }
   }
 
   //
@@ -154,17 +162,17 @@ MainObject::MainObject(QObject *parent,const char *name)
   // Initialize Data Structures
   //
   debug=false;
-  for(int i=0;i<RDCATCHD_MAX_CONNECTIONS;i++) {
+  for(unsigned i=0;i<RDCATCHD_MAX_CONNECTIONS;i++) {
     socket[i]=NULL;
     istate[i]=0;
     argnum[i]=0;
     argptr[i]=0;
     auth[i]=false;
-    catch_record_deck_status[i]=RDDeck::Offline;
-    catch_playout_deck_status[i]=RDDeck::Offline;
     catch_meter_enabled[i]=false;
   }
   for(int i=0;i<MAX_DECKS;i++) {
+    catch_record_deck_status[i]=RDDeck::Offline;
+    catch_playout_deck_status[i]=RDDeck::Offline;
     catch_record_status[i]=false;
     catch_record_id[i]=0;
     catch_record_aborting[i]=false;
@@ -211,13 +219,20 @@ MainObject::MainObject(QObject *parent,const char *name)
   //
   QString err (tr("ERROR rdcatchd aborting - "));
 
-  catch_db=RDInitDb (&err);
+  catch_db=RDInitDb(&schema,&err);
   if(!catch_db) {
     printf(err.ascii());
     exit(1);
   }
+  if((schema!=RD_VERSION_DATABASE)&&(!skip_db_check)) {
+    fprintf(stderr,
+	    "rdcatchd: database version mismatch, should be %u, is %u\n",
+	    RD_VERSION_DATABASE,schema);
+    exit(256);
+  }
   connect (RDDbStatus(),SIGNAL(logText(RDConfig::LogPriority,const QString &)),
 	   this,SLOT(log(RDConfig::LogPriority,const QString &)));
+
   //
   // Create RDCatchConf
   //
@@ -249,6 +264,11 @@ MainObject::MainObject(QObject *parent,const char *name)
   connect(catch_ripc,SIGNAL(gpiStateChanged(int,int,bool)),
 	  this,SLOT(gpiStateChangedData(int,int,bool)));
 
+  //
+  // System Configuration
+  //
+  catch_system=new RDSystem();
+
   //
   // Station Configuration
   //
@@ -257,7 +277,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   //
   // CAE Connection
   //
-  catch_cae=new RDCae(this,"catch_cae");
+  catch_cae=new RDCae(catch_rdstation,catch_config,this,"catch_cae");
   connect(catch_cae,SIGNAL(isConnected(bool)),
 	  this,SLOT(isConnectedData(bool)));
   connect(catch_cae,SIGNAL(recordLoaded(int,int)),
@@ -266,8 +286,8 @@ MainObject::MainObject(QObject *parent,const char *name)
 	  this,SLOT(recordingData(int,int)));
   connect(catch_cae,SIGNAL(recordStopped(int,int)),
 	  this,SLOT(recordStoppedData(int,int)));
-  connect(catch_cae,SIGNAL(recordUnloaded(int,int)),
-	  this,SLOT(recordUnloadedData(int,int)));
+  connect(catch_cae,SIGNAL(recordUnloaded(int,int,unsigned)),
+	  this,SLOT(recordUnloadedData(int,int,unsigned)));
   connect(catch_cae,SIGNAL(playLoaded(int)),
 	  this,SLOT(playLoadedData(int)));
   connect(catch_cae,SIGNAL(playing(int)),
@@ -276,7 +296,7 @@ MainObject::MainObject(QObject *parent,const char *name)
 	  this,SLOT(playStoppedData(int)));
   connect(catch_cae,SIGNAL(playUnloaded(int)),
 	  this,SLOT(playUnloadedData(int)));
-  catch_cae->connectHost("localhost",CAED_TCP_PORT,catch_config->password());
+  catch_cae->connectHost();
 
   //
   // Sound Initialization
@@ -390,6 +410,23 @@ MainObject::MainObject(QObject *parent,const char *name)
   connect(timer,SIGNAL(timeout()),this,SLOT(startupCartData()));
   timer->start(10000,true);
 
+  //
+  // Set Realtime Permissions
+  //
+  if(catch_config->useRealtime()) {
+    struct sched_param sp;
+    memset(&sp,0,sizeof(sp));
+    if(catch_config->realtimePriority()>0) {
+      sp.sched_priority=catch_config->realtimePriority()-1;
+    }
+    if(sched_setscheduler(getpid(),SCHED_FIFO,&sp)!=0) {
+      LogLine(RDConfig::LogWarning,
+	      QString().sprintf("unable to set realtime permissions, %s",
+				strerror(errno)));
+    }
+    mlockall(MCL_CURRENT|MCL_FUTURE);
+  }
+
   LogLine(RDConfig::LogNotice,"rdcatchd started");
 }
 
@@ -401,7 +438,7 @@ void MainObject::log(RDConfig::LogPriority prio,const QString &msg)
 
 void MainObject::newConnection(int fd)
 {
-  int i=0;
+  unsigned i=0;
 
   while((i<RDCATCHD_MAX_CONNECTIONS)&&(socket[i]!=NULL)) {
     i++;
@@ -500,13 +537,13 @@ void MainObject::startTimerData(int id)
 {
   int event=GetEvent(id);
   unsigned deck=catch_events[event].channel()-1;
-  bool waiting=false;
+  //  bool waiting=false;
 
   catch_events[event].setStatus(RDDeck::Idle);
   for(unsigned i=0;i<catch_events.size();i++) {
     if((catch_events[i].status()==RDDeck::Waiting)&&
        ((catch_events[i].channel()-1)==deck)) {
-      waiting=true;
+      //      waiting=true;
     }
   }
   WriteExitCodeById(id,RDRecording::Ok);
@@ -582,8 +619,6 @@ void MainObject::engineData(int id)
       BroadcastCommand(QString().sprintf("RE 0 %d %d %s!",RDDeck::Recording,
 					 catch_events[event].id(),
 				(const char *)catch_events[event].cutName()));
-      SendErrorMessage(&catch_events[event],"device busy",
-		       catch_conf->errorRml());
       return;
     }
   }
@@ -605,8 +640,6 @@ void MainObject::engineData(int id)
 		  sprintf("record aborted: no such cut: %s, id: %d",
 			  (const char *)catch_events[event].cutName(),
 			  catch_events[event].id()));
-	  SendErrorMessage(&catch_events[event],"no such cut",
-			   catch_conf->errorRml());
 	  return;
 	}
 	catch_record_card[catch_events[event].channel()-1]=-1;
@@ -687,8 +720,6 @@ void MainObject::engineData(int id)
 		  sprintf("playout aborted: no such cut: %s, id: %d",
 			  (const char *)catch_events[event].cutName(),
 			  catch_events[event].id()));
-	  SendErrorMessage(&catch_events[event],"no such cut",
-			   catch_conf->errorRml());
 	  return;
 	}
 	catch_playout_card[catch_events[event].channel()-129]=-1;
@@ -727,8 +758,6 @@ void MainObject::engineData(int id)
 		  QString().sprintf("macro aborted: no such cart: %u, id: %d",
 				    catch_events[event].macroCart(),
 				    catch_events[event].id()));
-	  SendErrorMessage(&catch_events[event],"no such cut",
-			   catch_conf->errorRml());
 	  return;
 	}
 	StartMacroEvent(event);
@@ -747,8 +776,6 @@ void MainObject::engineData(int id)
 		  sprintf("download aborted: no such cut: %s, id: %d",
 			  (const char *)catch_events[event].cutName(),
 			  catch_events[event].id()));
-	  SendErrorMessage(&catch_events[event],"no such cut",
-			   catch_conf->errorRml());
 	  return;
 	}
 
@@ -793,16 +820,8 @@ void MainObject::engineData(int id)
 		  sprintf("upload aborted: no such cut: %s, id: %d",
 			  (const char *)catch_events[event].cutName(),
 			  catch_events[event].id()));
-	  SendErrorMessage(&catch_events[event],"no such cut",
-			   catch_conf->errorRml());
 	  return;
 	}
-	/*
-	catch_events[event].
-	  setResolvedUrl(RDDateTimeDecode(catch_events[event].url(),
-	       QDateTime(date.addDays(catch_events[event].eventdateOffset()),
-	       current_time)));
-	*/
 	StartUploadEvent(event);
 	break;
   }
@@ -879,7 +898,7 @@ void MainObject::recordStoppedData(int card,int stream)
 }
 
 
-void MainObject::recordUnloadedData(int card,int stream)
+void MainObject::recordUnloadedData(int card,int stream,unsigned msecs)
 {
   int deck=GetRecordDeck(card,stream);
   if(deck<1) {
@@ -900,7 +919,8 @@ void MainObject::recordUnloadedData(int card,int stream)
   }
 
   if(catch_events[event].normalizeLevel()==0) {
-    CheckInRecording(catch_record_name[deck-1],catch_record_threshold[deck-1]);
+    CheckInRecording(catch_record_name[deck-1],&catch_events[event],msecs,
+		     catch_record_threshold[deck-1]);
   }
   else {
     StartBatch(catch_events[event].id());
@@ -1181,8 +1201,6 @@ bool MainObject::StartRecording(int event)
     LogLine(RDConfig::LogNotice,QString().
 	    sprintf("device busy for deck: %d, event: %d | in use by event: %d",
 		    deck,catch_events[event].id(),catch_record_id[deck-1]));
-    SendErrorMessage(&catch_events[event],"device busy",
-		     catch_conf->errorRml());
     return false;
   }
 
@@ -1439,7 +1457,7 @@ void MainObject::StartDownloadEvent(int event)
   catch_active_xloads.push_back(event);
   if(!catch_xload_timer->isActive()) {
     catch_xload_timer->start(XLOAD_UPDATE_INTERVAL);
-  }
+  } 
   BroadcastCommand(QString().sprintf("RE 0 %d %d!",
 				     RDDeck::Recording,
 				     catch_events[event].id()));
@@ -1453,7 +1471,7 @@ void MainObject::StartUploadEvent(int event)
   catch_active_xloads.push_back(event);
   if(!catch_xload_timer->isActive()) {
     catch_xload_timer->start(XLOAD_UPDATE_INTERVAL);
-  }
+  } 
   BroadcastCommand(QString().sprintf("RE 0 %d %d!",RDDeck::Recording,
 				     catch_events[event].id()));
   StartBatch(catch_events[event].id());
@@ -1515,7 +1533,7 @@ void MainObject::SendFullStatus(int ch)
 
 void MainObject::SendMeterLevel(int deck,short levels[2])
 {
-  for(int i=0;i<RDCATCHD_MAX_CONNECTIONS;i++) {
+  for(unsigned i=0;i<RDCATCHD_MAX_CONNECTIONS;i++) {
     if(catch_meter_enabled[i]) {
       EchoCommand(i,QString().sprintf("RM %d 0 %d!",deck,(int)levels[0]));
       EchoCommand(i,QString().sprintf("RM %d 1 %d!",deck,(int)levels[1]));
@@ -1774,18 +1792,21 @@ void MainObject::DispatchCommand(int ch)
     if(sscanf(args[ch][2],"%d",&code)!=1) {
       return;
     }
+    str="";
+    for(int i=3;i<argnum[ch];i++) {
+      str+=QString(args[ch][i])+" ";
+      str.stripWhiteSpace();
+    }
     if((event=GetEvent(id))<0) {
       return;
     }
-    WriteExitCode(event,(RDRecording::ExitCode)code);
+    WriteExitCode(event,(RDRecording::ExitCode)code,str);
     BroadcastCommand(QString().sprintf("RE 0 %d %d!",RDDeck::Idle,id));
     if((RDRecording::ExitCode)code==RDRecording::Ok) {
       BroadcastCommand(QString().sprintf("RE 0 %d %d!",RDDeck::Idle,id));
     }
     else {
       BroadcastCommand(QString().sprintf("RE 0 %d %d!",RDDeck::Offline,id));
-      SendExitErrorMessage(&catch_events[event],tr("Generic error"),
-			   catch_conf->errorRml());
     }
   }
 }
@@ -1817,9 +1838,9 @@ void MainObject::EchoCommand(int ch,const char *command)
 void MainObject::BroadcastCommand(const char *command,int except_ch)
 {
 //  LogLine(RDConfig::LogDebug,QString().sprintf("rdcatchd: BroadcastCommand(%s)",command));
-  for(int i=0;i<RDCATCHD_MAX_CONNECTIONS;i++) {
+  for(unsigned i=0;i<RDCATCHD_MAX_CONNECTIONS;i++) {
     if(socket[i]!=NULL) {
-      if(i!=except_ch) {
+      if((int)i!=except_ch) {
 	EchoCommand(i,command);
       }
     }
@@ -1877,7 +1898,7 @@ QString MainObject::LoadEventSql()
                   END_MATRIX,END_LINE,URL,URL_USERNAME,URL_PASSWORD,\
                   QUALITY,NORMALIZE_LEVEL,ALLOW_MULT_RECS,\
                   MAX_GPI_REC_LENGTH,DESCRIPTION,FEED_ID,\
-                  EVENTDATE_OFFSET from RECORDINGS");
+                  EVENTDATE_OFFSET,ENABLE_METADATA from RECORDINGS");
 }
 
 
@@ -1904,7 +1925,8 @@ void MainObject::LoadEvent(RDSqlQuery *q,CatchEvent *e,bool add)
   e->setEnddateOffset(q->value(18).toUInt());
   e->setFormat((RDCae::AudioCoding)q->value(19).toInt());
   e->setChannels(q->value(20).toInt());
-  e->setSampleRate(q->value(21).toInt());
+  e->setSampleRate(catch_system->sampleRate());
+  //e->setSampleRate(q->value(21).toInt());
   e->setBitrate(q->value(22).toInt());
   e->setMacroCart(q->value(23).toInt());
   e->setSwitchInput(q->value(24).toInt());
@@ -1931,6 +1953,7 @@ void MainObject::LoadEvent(RDSqlQuery *q,CatchEvent *e,bool add)
   e->setDescription(q->value(44).toString());
   e->setFeedId(q->value(45).toUInt());
   e->setEventdateOffset(q->value(46).toInt());
+  e->setEnableMetadata(RDBool(q->value(47).toString()));
 
   if(add) {
     if(e->startType()==RDRecording::GpiStart) {
@@ -2268,10 +2291,17 @@ void MainObject::LoadHeartbeat()
 }
 
 
-void MainObject::CheckInRecording(QString cutname,unsigned threshold)
+void MainObject::CheckInRecording(QString cutname,CatchEvent *evt,
+				  unsigned msecs,unsigned threshold)
 {
   RDCut *cut=new RDCut(cutname);
-  cut->checkInRecording(catch_config->stationName());
+  RDSettings *s=new RDSettings();
+  s->setFormat((RDSettings::Format)evt->format());
+  s->setSampleRate(evt->sampleRate());
+  s->setBitRate(evt->bitrate());
+  s->setChannels(evt->channels());
+  cut->checkInRecording(catch_config->stationName(),s,msecs);
+  delete s;
   cut->autoTrim(RDCut::AudioBoth,-threshold);
   RDCart *cart=new RDCart(cut->cartNumber());
   cart->updateLength();
@@ -2368,19 +2398,48 @@ RDRecording::ExitCode MainObject::ReadExitCode(int event)
 }
 
 
-void MainObject::WriteExitCode(int event,RDRecording::ExitCode code)
+void MainObject::WriteExitCode(int event,RDRecording::ExitCode code,
+			       const QString &err_text)
 {
-  QString sql=QString().sprintf("update RECORDINGS set EXIT_CODE=%d\
-                                 where ID=%d",code,catch_events[event].id());
+  QString sql=QString().sprintf("update RECORDINGS set EXIT_CODE=%d,\
+                                 EXIT_TEXT=\"%s\"\
+                                 where ID=%d",code,
+				(const char *)RDEscapeString(err_text),
+				catch_events[event].id());
   RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
+  switch(code) {
+  case RDRecording::Ok:
+  case RDRecording::Downloading:
+  case RDRecording::Uploading:
+  case RDRecording::RecordActive:
+  case RDRecording::PlayActive:
+  case RDRecording::Waiting:
+    break;
+
+  case RDRecording::ServerError:
+  case RDRecording::InternalError:
+    SendErrorMessage(&catch_events[event],
+		     RDRecording::exitString(code)+": "+err_text,
+		     catch_conf->errorRml());
+    break;
+
+  default:
+    SendErrorMessage(&catch_events[event],RDRecording::exitString(code),
+		     catch_conf->errorRml());
+    break;
+  }
 }
 
 
-void MainObject::WriteExitCodeById(int id,RDRecording::ExitCode code)
+void MainObject::WriteExitCodeById(int id,RDRecording::ExitCode code,
+				   const QString &err_text)
 {
-  QString sql=QString().sprintf("update RECORDINGS set EXIT_CODE=%d\
-                                 where ID=%d",code,id);
+  QString sql=QString().sprintf("update RECORDINGS set EXIT_CODE=%d,\
+                                 EXIT_TEXT=\"%s\" \
+                                 where ID=%d",code,
+				(const char *)RDEscapeString(err_text),
+				id);
   RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
 }
@@ -2421,15 +2480,6 @@ void QApplication::saveState(QSessionManager &sm) {
 };
 
 
-void MainObject::SendExitErrorMessage(CatchEvent *event,
-				      const QString &err_desc,QString rml)
-{
-  if(SendErrorMessage(event,err_desc,rml)) {
-    return;
-  }
-}
-
-
 bool MainObject::SendErrorMessage(CatchEvent *event,const QString &err_desc,
 				  QString rml)
 {
@@ -2512,6 +2562,7 @@ void MainObject::StartDropboxes()
 {
   QString sql;
   RDSqlQuery *q;
+  RDSqlQuery *q1;
 
   //
   // Kill Old Instances
@@ -2521,52 +2572,69 @@ void MainObject::StartDropboxes()
   //
   // Launch Dropbox Configurations
   //
-  sql=QString().sprintf("select GROUP_NAME,PATH,NORMALIZATION_LEVEL,\
-                         AUTOTRIM_LEVEL,TO_CART,USE_CARTCHUNK_ID,\
-                         TITLE_FROM_CARTCHUNK_ID,DELETE_CUTS,\
-                         METADATA_PATTERN,FIX_BROKEN_FORMATS,LOG_PATH,\
-                         DELETE_SOURCE,STARTDATE_OFFSET,ENDDATE_OFFSET,ID \
-                         from DROPBOXES where STATION_NAME=\"%s\"",
-			(const char *)catch_config->stationName());
+  sql=QString("select ID,GROUP_NAME,PATH,NORMALIZATION_LEVEL,")+
+    "AUTOTRIM_LEVEL,TO_CART,USE_CARTCHUNK_ID,TITLE_FROM_CARTCHUNK_ID,"+
+    "DELETE_CUTS,METADATA_PATTERN,FIX_BROKEN_FORMATS,LOG_PATH,"+
+    "DELETE_SOURCE,STARTDATE_OFFSET,ENDDATE_OFFSET,ID,"+
+    "IMPORT_CREATE_DATES,CREATE_STARTDATE_OFFSET,"+
+    "CREATE_ENDDATE_OFFSET,SET_USER_DEFINED "+
+    "from DROPBOXES where STATION_NAME=\""+
+    RDEscapeString(catch_config->stationName())+"\"";
   q=new RDSqlQuery(sql);
   while(q->next()) {
     QString cmd=QString().
       sprintf("nice rdimport --persistent-dropbox-id=%d --drop-box --log-mode",
-	      q->value(14).toInt());
-    cmd+=
-      QString().sprintf(" --normalization-level=%d",q->value(2).toInt()/100);
-    cmd+=
-      QString().sprintf(" --autotrim-level=%d",q->value(3).toInt()/100);
-    if(q->value(4).toUInt()>0) {
-      cmd+=QString().sprintf(" --to-cart=%u",q->value(4).toUInt());
+	      q->value(15).toInt());
+    sql=QString("select SCHED_CODE from DROPBOX_SCHED_CODES where ")+
+      QString().sprintf("DROPBOX_ID=%d",q->value(0).toInt());
+    q1=new RDSqlQuery(sql);
+    while(q1->next()) {
+      cmd+=QString(" --add-scheduler-code=\"")+q1->value(0).toString()+"\"";
     }
-    if(q->value(5).toString()=="Y") {
-      cmd+=" --use_cartchunk-cutid";
+    delete q1;
+    cmd+=
+      QString().sprintf(" --normalization-level=%d",q->value(3).toInt()/100);
+    cmd+=
+      QString().sprintf(" --autotrim-level=%d",q->value(4).toInt()/100);
+    if(q->value(5).toUInt()>0) {
+      cmd+=QString().sprintf(" --to-cart=%u",q->value(5).toUInt());
     }
     if(q->value(6).toString()=="Y") {
-      cmd+=" --title-from-cartchunk-cutid";
+      cmd+=" --use-cartchunk-cutid";
     }
     if(q->value(7).toString()=="Y") {
+      cmd+=" --title-from-cartchunk-cutid";
+    }
+    if(q->value(8).toString()=="Y") {
       cmd+=" --delete-cuts";
     }
-    if(!q->value(8).toString().isEmpty()) {
+    if(!q->value(9).toString().isEmpty()) {
       cmd+=QString().sprintf(" \"--metadata-pattern=%s\"",
-			     (const char *)q->value(8).toString());
+			     (const char *)q->value(9).toString());
     }
-    if(q->value(9).toString()=="Y") {
+    if(q->value(10).toString()=="Y") {
       cmd+=" --fix-broken-formats";
     }
-    if(q->value(11).toString()=="Y") {
+    if(q->value(12).toString()=="Y") {
       cmd+=" --delete-source";
     }
-    cmd+=QString().sprintf(" --startdate-offset=%d",q->value(12).toInt());
-    cmd+=QString().sprintf(" --enddate-offset=%d",q->value(13).toInt());
-    cmd+=QString().sprintf(" %s \"%s\"",(const char *)q->value(0).toString(),
-			   (const char *)q->value(1).toString());
-    if(!q->value(10).toString().isEmpty()) {
+    if(q->value(16).toString()=="Y") {
+      cmd+=QString().sprintf(" --create-startdate-offset=%d",
+			     q->value(17).toInt());
+      cmd+=QString().sprintf(" --create-enddate-offset=%d",
+			     q->value(18).toInt());
+    }
+    if(!q->value(19).toString().isEmpty()) {
+      cmd+=" --set-user-defined="+RDEscapeString(q->value(19).toString());
+    }
+    cmd+=QString().sprintf(" --startdate-offset=%d",q->value(13).toInt());
+    cmd+=QString().sprintf(" --enddate-offset=%d",q->value(14).toInt());
+    cmd+=QString().sprintf(" %s \"%s\"",(const char *)q->value(1).toString(),
+			   (const char *)q->value(2).toString());
+    if(!q->value(11).toString().isEmpty()) {
       cmd+=QString().sprintf(" >> %s 2>> %s",
-			     (const char *)q->value(10).toString(),
-			     (const char *)q->value(10).toString());
+			     (const char *)q->value(11).toString(),
+			     (const char *)q->value(11).toString());
     }
     else {
       cmd+=" > /dev/null 2> /dev/null";
@@ -2628,7 +2696,7 @@ void MainObject::StartRmlRecording(int chan,int cartnum,int cutnum,int maxlen)
   catch_events.back().
     setFormat((RDCae::AudioCoding)deck->defaultFormat());
   catch_events.back().setChannels(deck->defaultChannels());
-  catch_events.back().setSampleRate(deck->defaultSamprate());
+  catch_events.back().setSampleRate(catch_system->sampleRate());
   catch_events.back().setBitrate(deck->defaultBitrate());
   catch_events.back().setNormalizeLevel(0);
   StartRecording(catch_events.size()-1);
