@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2013 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: lib_listview.h,v 1.1.2.1 2013/12/27 22:12:26 cvs Exp $
+//      $Id: lib_listview.h,v 1.1.2.2 2014/01/08 00:00:51 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,6 +34,11 @@ class LibListView : public RDListView
 
  protected:
   void contentsMousePressEvent(QMouseEvent *e);
+  void contentsMouseMoveEvent(QMouseEvent *e);
+  void contentsMouseReleaseEvent(QMouseEvent *e);
+
+ private:
+  int list_move_count;
 };
 
 
