@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: starguide3.h,v 1.4 2007/09/14 14:07:00 fredg Exp $
+//      $Id: starguide3.h,v 1.9 2010/08/03 23:39:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,8 +23,6 @@
 #ifndef STARGUIDE3_H
 #define STARGUIDE3_H
 
-using namespace std;
-
 #include <vector>
 
 #include <qobject.h>
@@ -34,23 +32,25 @@ using namespace std;
 #include <rdmacro.h>
 #include <rdtty.h>
 
+#include <switcher.h>
 #include <starguide_feed.h>
 
-class StarGuide3 : public QObject
+class StarGuide3 : public Switcher
 {
  Q_OBJECT
  public:
   StarGuide3(RDMatrix *matrix,QObject *parent=0,const char *name=0);
   ~StarGuide3();
+  RDMatrix::Type type();
+  unsigned gpiQuantity();
+  unsigned gpoQuantity();
+  bool primaryTtyActive();
+  bool secondaryTtyActive();
   void processCommand(RDMacro *cmd);
-  void processStatus(char *buf,int size);
-
- signals:
-  void rmlEcho(RDMacro *cmd);
 
  private:
   RDTTYDevice *sg_device;
-  vector<StarGuideFeed> sg_feed;
+  std::vector<StarGuideFeed> sg_feed;
   int sg_inputs;
   int sg_outputs;
 };
